@@ -10,6 +10,7 @@
 
 #include <QDebug>
 #include <QFile>
+#include <QTcpServer>
 #include <QTest>
 
 FakeServer::FakeServer(QObject *parent)
@@ -147,7 +148,7 @@ bool FakeServer::isAllScenarioDone() const
 {
     QMutexLocker locker(&m_mutex);
 
-    for (const auto &scenario : qAsConst(m_scenarios)) {
+    for (const auto &scenario : std::as_const(m_scenarios)) {
         if (!scenario.isEmpty()) {
             qDebug() << scenario;
             return false;
