@@ -16,7 +16,6 @@
 #include <KAuthorized>
 #include <QHash>
 #include <QPointer>
-#include <kwidgetsaddons_version.h>
 
 #include "mailtransport_debug.h"
 #include <KLocalizedString>
@@ -65,7 +64,7 @@ Q_GLOBAL_STATIC(SessionPool, s_sessionPool)
 class SmtpJobPrivate
 {
 public:
-    SmtpJobPrivate(SmtpJob *parent)
+    explicit SmtpJobPrivate(SmtpJob *parent)
         : q(parent)
     {
     }
@@ -103,7 +102,6 @@ SmtpJob::~SmtpJob()
             }
         }
     }
-    delete d;
 }
 
 void SmtpJob::doStart()
@@ -134,6 +132,20 @@ void SmtpJob::startSmtpJob()
         d->session = new KSmtp::Session(transport()->host(), transport()->port());
         d->session->setUseNetworkProxy(transport()->useProxy());
         d->session->setUiProxy(d->uiProxy);
+        switch (transport()->encryption()) {
+        case Transport::EnumEncryption::None:
+            d->session->setEncryptionMode(KSmtp::Session::Unencrypted);
+            break;
+        case Transport::EnumEncryption::TLS:
+            d->session->setEncryptionMode(KSmtp::Session::STARTTLS);
+            break;
+        case Transport::EnumEncryption::SSL:
+            d->session->setEncryptionMode(KSmtp::Session::TLS);
+            break;
+        default:
+            qCWarning(MAILTRANSPORT_SMTP_LOG) << "Unknown encryption mode" << transport()->encryption();
+            break;
+        }
         if (transport()->specifyHostname()) {
             d->session->setCustomHostname(transport()->localHostname());
         }
@@ -233,9 +245,7 @@ void SmtpJob::startLoginJob()
         dlg->addCommentLine(QString(), transport()->name());
         dlg->setUsername(user);
         dlg->setPassword(passwd);
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
         dlg->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
-#endif
 
         connect(this, &KJob::result, dlg, &QDialog::reject);
 
@@ -298,21 +308,6 @@ void SmtpJobPrivate::doLogin()
         break;
     }
 
-    switch (q->transport()->encryption()) {
-    case Transport::EnumEncryption::None:
-        login->setEncryptionMode(KSmtp::LoginJob::Unencrypted);
-        break;
-    case Transport::EnumEncryption::TLS:
-        login->setEncryptionMode(KSmtp::LoginJob::STARTTLS);
-        break;
-    case Transport::EnumEncryption::SSL:
-        login->setEncryptionMode(KSmtp::LoginJob::SSLorTLS);
-        break;
-    default:
-        qCWarning(MAILTRANSPORT_SMTP_LOG) << "Unknown encryption mode" << q->transport()->encryption();
-        break;
-    }
-
     q->connect(login, &KJob::result, q, &SmtpJob::slotResult);
     q->addSubjob(login);
     login->start();
@@ -327,6 +322,7 @@ void SmtpJob::startSendJob()
     send->setCc(cc());
     send->setBcc(bcc());
     send->setData(data());
+    send->setDeliveryStatusNotification(deliveryStatusNotification());
 
     addSubjob(send);
     send->start();
