@@ -7,7 +7,6 @@
 #include "transportpluginmanager.h"
 #include "mailtransport_debug.h"
 #include <KPluginFactory>
-#include <KPluginLoader>
 #include <kpluginmetadata.h>
 
 #include <MailTransport/TransportAbstractPlugin>
@@ -21,6 +20,7 @@ class MailTransportPluginInfo
 public:
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
+    KPluginMetaData data;
     MailTransport::TransportAbstractPlugin *plugin = nullptr;
 };
 
@@ -44,18 +44,18 @@ public:
     void loadPlugin(MailTransportPluginInfo *item);
     QVector<MailTransport::TransportAbstractPlugin *> pluginsList() const;
     QVector<MailTransportPluginInfo> mPluginList;
-    bool initializePlugins();
+    void initializePlugins();
 
 private:
     TransportPluginManager *q;
 };
 
-bool TransportPluginManagerPrivate::initializePlugins()
+void TransportPluginManagerPrivate::initializePlugins()
 {
     if (!mPluginList.isEmpty()) {
-        return true;
+        return;
     }
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("mailtransport"));
+    const QVector<KPluginMetaData> plugins = KPluginMetaData::findPlugins(QStringLiteral("mailtransport"));
 
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
@@ -65,6 +65,7 @@ bool TransportPluginManagerPrivate::initializePlugins()
 
         info.metaDataFileNameBaseName = QFileInfo(data.fileName()).baseName();
         info.metaDataFileName = data.fileName();
+        info.data = data;
         if (pluginVersion() == data.version()) {
             info.plugin = nullptr;
             mPluginList.push_back(info);
@@ -76,17 +77,14 @@ bool TransportPluginManagerPrivate::initializePlugins()
     for (QVector<MailTransportPluginInfo>::iterator it = mPluginList.begin(); it != end; ++it) {
         loadPlugin(&(*it));
     }
-    return true;
 }
 
 void TransportPluginManagerPrivate::loadPlugin(MailTransportPluginInfo *item)
 {
-    KPluginLoader pluginLoader(item->metaDataFileName);
-    if (pluginLoader.factory()) {
-        item->plugin = pluginLoader.factory()->create<MailTransport::TransportAbstractPlugin>(q, QVariantList() << item->metaDataFileNameBaseName);
-        if (item->plugin) {
-            QObject::connect(item->plugin, &TransportAbstractPlugin::updatePluginList, q, &TransportPluginManager::updatePluginList);
-        }
+    if (auto plugin =
+            KPluginFactory::instantiatePlugin<MailTransport::TransportAbstractPlugin>(item->data, q, QVariantList() << item->metaDataFileNameBaseName).plugin) {
+        item->plugin = plugin;
+        QObject::connect(plugin, &TransportAbstractPlugin::updatePluginList, q, &TransportPluginManager::updatePluginList);
     }
 }
 
@@ -108,10 +106,7 @@ TransportPluginManager::TransportPluginManager(QObject *parent)
 {
 }
 
-TransportPluginManager::~TransportPluginManager()
-{
-    delete d;
-}
+TransportPluginManager::~TransportPluginManager() = default;
 
 TransportPluginManager *TransportPluginManager::self()
 {
