@@ -12,11 +12,14 @@
 
 #include <KCompositeJob>
 
+#include <memory>
+
 class QBuffer;
 
 namespace MailTransport
 {
 class Transport;
+class TransportJobPrivate;
 
 /**
   Abstract base class for all mail transport jobs.
@@ -77,6 +80,11 @@ public:
     */
     Transport *transport() const;
 
+    /**
+       Sets the content of the mail.
+    */
+    void setDeliveryStatusNotification(bool enabled);
+
 protected:
     /**
       Creates a new mail transport job.
@@ -123,10 +131,14 @@ protected:
     */
     virtual void doStart() = 0;
 
+    /**
+      Returns true if DSN is enabled.
+    */
+    Q_REQUIRED_RESULT bool deliveryStatusNotification() const;
+
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<TransportJobPrivate> const d;
     //@endcond
 };
 } // namespace MailTransport
