@@ -4,14 +4,15 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORTCOMBOBOX_H
-#define MAILTRANSPORT_TRANSPORTCOMBOBOX_H
+#pragma once
 
 #include <mailtransport_export.h>
 #include <transportbase.h>
 
 #include <QComboBox>
 
+#include <memory>
+
 class TransportComboBoxPrivate;
 
 namespace MailTransport
@@ -62,8 +63,7 @@ public Q_SLOTS:
     void updateComboboxList();
 
 private:
-    TransportComboBoxPrivate *const d;
+    std::unique_ptr<TransportComboBoxPrivate> const d;
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORTCOMBOBOX_H
