@@ -12,12 +12,12 @@
 */
 
 #include "transportconfigwidget.h"
-#include "transportconfigwidget_p.h"
 #include "transport.h"
+#include "transportconfigwidget_p.h"
 #include "transportmanager.h"
 
-#include <KConfigDialogManager>
 #include "mailtransport_debug.h"
+#include <KConfigDialogManager>
 
 using namespace MailTransport;
 
@@ -35,10 +35,7 @@ TransportConfigWidget::TransportConfigWidget(TransportConfigWidgetPrivate &dd, T
     init(transport);
 }
 
-TransportConfigWidget::~TransportConfigWidget()
-{
-    delete d_ptr;
-}
+TransportConfigWidget::~TransportConfigWidget() = default;
 
 void TransportConfigWidget::init(Transport *transport)
 {
