@@ -13,8 +13,12 @@
 
 #include <QWidget>
 
+#include <memory>
+
 namespace MailTransport
 {
+class TransportManagementWidgetPrivate;
+
 /**
   A widget to manage mail transports.
 */
@@ -35,8 +39,7 @@ public:
     ~TransportManagementWidget() override;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<TransportManagementWidgetPrivate> const d;
 };
 } // namespace MailTransport
 
