@@ -6,9 +6,9 @@
 
 #include "attributetest.h"
 
+#include <Akonadi/AttributeFactory>
 #include <addressattribute.h>
-#include <attributefactory.h>
-#include <qtest_akonadi.h>
+#include <akonadi/qtest_akonadi.h>
 
 #include <kmailtransportakonadi/dispatchmodeattribute.h>
 #include <kmailtransportakonadi/errorattribute.h>
