@@ -9,8 +9,8 @@
 #include <QObject>
 #include <QString>
 
-#include <collection.h>
-#include <item.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 class FilterActionTest : public QObject
 {
