@@ -8,22 +8,22 @@
 
 #include <QStringList>
 
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentManager>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionStatistics>
+#include <Akonadi/CollectionStatisticsJob>
+#include <Akonadi/Control>
+#include <Akonadi/ItemDeleteJob>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 #include <addressattribute.h>
-#include <agentinstance.h>
-#include <agentmanager.h>
-#include <collection.h>
-#include <collectionstatistics.h>
-#include <collectionstatisticsjob.h>
-#include <control.h>
-#include <itemdeletejob.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <akonadi/qtest_akonadi.h>
 #include <messageflags.h>
-#include <qtest_akonadi.h>
 #include <specialmailcollections.h>
 #include <specialmailcollectionsrequestjob.h>
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
 #include <QSignalSpy>
 #include <kmailtransportakonadi/dispatchmodeattribute.h>
@@ -48,8 +48,9 @@ void MessageQueueJobTest::initTestCase()
 
     // Switch MDA offline to avoid spam.
     AgentInstance mda = AgentManager::self()->instance(QStringLiteral("akonadi_maildispatcher_agent"));
-    QVERIFY(mda.isValid());
-    mda.setIsOnline(false);
+    if (mda.isValid()) {
+        mda.setIsOnline(false);
+    }
 
     // check that outbox is empty
     auto rjob = new SpecialMailCollectionsRequestJob(this);
