@@ -6,7 +6,7 @@
 
 #pragma once
 
-#include <attribute.h>
+#include <Akonadi/Attribute>
 
 /* Attribute used for testing by various unit tests. */
 class TestAttribute : public Akonadi::Attribute
