@@ -8,28 +8,25 @@
 
 #include "mailtransportakonadi_debug.h"
 
-#include <attributefactory.h>
+#include <Akonadi/AttributeFactory>
 
 using namespace Akonadi;
 using namespace MailTransport;
 
-class Q_DECL_HIDDEN DispatchModeAttribute::Private
+class MailTransport::DispatchModeAttributePrivate
 {
 public:
-    DispatchMode mMode;
+    DispatchModeAttribute::DispatchMode mMode;
     QDateTime mDueDate;
 };
 
 DispatchModeAttribute::DispatchModeAttribute(DispatchMode mode)
-    : d(new Private)
+    : d(new DispatchModeAttributePrivate)
 {
     d->mMode = mode;
 }
 
-DispatchModeAttribute::~DispatchModeAttribute()
-{
-    delete d;
-}
+DispatchModeAttribute::~DispatchModeAttribute() = default;
 
 DispatchModeAttribute *DispatchModeAttribute::clone() const
 {
