@@ -4,17 +4,20 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_DISPATCHMODEATTRIBUTE_H
-#define MAILTRANSPORT_DISPATCHMODEATTRIBUTE_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
 #include <QDateTime>
 
-#include <attribute.h>
+#include <Akonadi/Attribute>
+
+#include <memory>
 
 namespace MailTransport
 {
+class DispatchModeAttributePrivate;
+
 /**
   Attribute determining how and when a message from the outbox should be
   dispatched.  Messages can be sent immediately, sent only when the user
@@ -78,9 +81,7 @@ public:
     void setSendAfter(const QDateTime &date);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<DispatchModeAttributePrivate> const d;
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_DISPATCHMODEATTRIBUTE_H
