@@ -9,22 +9,19 @@
 using namespace Akonadi;
 using namespace MailTransport;
 
-class Q_DECL_HIDDEN ErrorAttribute::Private
+class MailTransport::ErrorAttributePrivate
 {
 public:
     QString mMessage;
 };
 
 ErrorAttribute::ErrorAttribute(const QString &msg)
-    : d(new Private)
+    : d(new ErrorAttributePrivate)
 {
     d->mMessage = msg;
 }
 
-ErrorAttribute::~ErrorAttribute()
-{
-    delete d;
-}
+ErrorAttribute::~ErrorAttribute() = default;
 
 ErrorAttribute *ErrorAttribute::clone() const
 {
