@@ -4,17 +4,20 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_ERRORATTRIBUTE_H
-#define MAILTRANSPORT_ERRORATTRIBUTE_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
 #include <QString>
 
-#include <attribute.h>
+#include <Akonadi/Attribute>
+
+#include <memory>
 
 namespace MailTransport
 {
+class ErrorAttributePrivate;
+
 /**
  * @short An Attribute to mark messages that failed to be sent.
  *
@@ -56,10 +59,8 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<ErrorAttributePrivate> const d;
     //@endcond
 };
 }
 
-#endif
