@@ -6,23 +6,23 @@
 
 #include "filteractionjob_p.h"
 
-#include <collection.h>
-#include <itemfetchjob.h>
-#include <itemfetchscope.h>
+#include <Akonadi/Collection>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
 
 #include "mailtransportakonadi_debug.h"
 
 using namespace Akonadi;
 
-class Q_DECL_HIDDEN Akonadi::FilterActionJob::Private
+class Akonadi::FilterActionJobPrivate
 {
 public:
-    Private(FilterActionJob *qq)
+    FilterActionJobPrivate(FilterActionJob *qq)
         : q(qq)
     {
     }
 
-    ~Private()
+    ~FilterActionJobPrivate()
     {
         delete functor;
     }
@@ -39,21 +39,21 @@ public:
     void traverseItems();
 };
 
-void FilterActionJob::Private::fetchResult(KJob *job)
+void FilterActionJobPrivate::fetchResult(KJob *job)
 {
     if (job->error()) {
         // KCompositeJob takes care of errors.
         return;
     }
 
-    auto fjob = dynamic_cast<ItemFetchJob *>(job);
+    auto fjob = qobject_cast<ItemFetchJob *>(job);
     Q_ASSERT(fjob);
     Q_ASSERT(items.isEmpty());
     items = fjob->items();
     traverseItems();
 }
 
-void FilterActionJob::Private::traverseItems()
+void FilterActionJobPrivate::traverseItems()
 {
     Q_ASSERT(functor);
     qCDebug(MAILTRANSPORTAKONADI_LOG) << "Traversing" << items.count() << "items.";
@@ -77,7 +77,7 @@ FilterAction::~FilterAction()
 
 FilterActionJob::FilterActionJob(const Item &item, FilterAction *functor, QObject *parent)
     : TransactionSequence(parent)
-    , d(new Private(this))
+    , d(new FilterActionJobPrivate(this))
 {
     d->functor = functor;
     d->items << item;
@@ -85,7 +85,7 @@ FilterActionJob::FilterActionJob(const Item &item, FilterAction *functor, QObjec
 
 FilterActionJob::FilterActionJob(const Item::List &items, FilterAction *functor, QObject *parent)
     : TransactionSequence(parent)
-    , d(new Private(this))
+    , d(new FilterActionJobPrivate(this))
 {
     d->functor = functor;
     d->items = items;
@@ -93,17 +93,14 @@ FilterActionJob::FilterActionJob(const Item::List &items, FilterAction *functor,
 
 FilterActionJob::FilterActionJob(const Collection &collection, FilterAction *functor, QObject *parent)
     : TransactionSequence(parent)
-    , d(new Private(this))
+    , d(new FilterActionJobPrivate(this))
 {
     d->functor = functor;
     Q_ASSERT(collection.isValid());
     d->collection = collection;
 }
 
-FilterActionJob::~FilterActionJob()
-{
-    delete d;
-}
+FilterActionJob::~FilterActionJob() = default;
 
 void FilterActionJob::doStart()
 {
