@@ -8,8 +8,10 @@
 
 #include <mailtransportakonadi_export.h>
 
-#include <item.h>
-#include <transactionsequence.h>
+#include <Akonadi/Item>
+#include <Akonadi/TransactionSequence>
+
+#include <memory>
 
 namespace Akonadi
 {
@@ -92,6 +94,7 @@ public:
     virtual Akonadi::Job *itemAction(const Akonadi::Item &item, Akonadi::FilterActionJob *parent) const = 0;
 };
 
+class FilterActionJobPrivate;
 /**
  * @short Job to filter and apply an action on a set of items.
  *
@@ -156,8 +159,8 @@ protected:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    friend class FilterActionJobPrivate;
+    std::unique_ptr<FilterActionJobPrivate> const d;
     //@endcond
 };
 } // namespace Akonadi
