@@ -7,8 +7,9 @@
 #include "akonadimailtransportplugin.h"
 #include "mailtransportplugin_akonadi_debug.h"
 #include "resourcesendjob_p.h"
-#include <AkonadiCore/AgentInstanceCreateJob>
-#include <AkonadiCore/AgentManager>
+#include <Akonadi/AgentConfigurationDialog>
+#include <Akonadi/AgentInstanceCreateJob>
+#include <Akonadi/AgentManager>
 #include <KPluginFactory>
 #include <MailTransport/Transport>
 
@@ -48,7 +49,8 @@ QVector<MailTransport::TransportAbstractPluginInfo> AkonadiMailTransportPlugin::
 {
     QVector<MailTransport::TransportAbstractPluginInfo> lst;
 
-    for (const AgentType &atype : AgentManager::self()->types()) {
+    const auto types{AgentManager::self()->types()};
+    for (const AgentType &atype : types) {
         // TODO probably the string "MailTransport" should be #defined somewhere
         // and used like that in the resources (?)
         if (atype.capabilities().contains(QLatin1String("MailTransport"))) {
@@ -71,7 +73,9 @@ bool AkonadiMailTransportPlugin::configureTransport(const QString &identifier, M
         qCWarning(MAILTRANSPORT_AKONADI_LOG) << "Invalid resource instance" << transport->host();
         return false;
     }
-    instance.configure(parent); // Async...
+    QPointer<Akonadi::AgentConfigurationDialog> dlg = new Akonadi::AgentConfigurationDialog(instance, parent); // Async...
+    dlg->exec();
+    delete dlg;
     transport->save();
     return true; // No way to know here if the user cancelled or not.
 }
