@@ -8,10 +8,10 @@
 #include "resourcesendjob_p.h"
 #include "transport.h"
 
-#include <kmime/kmime_message.h>
+#include <KMime/KMimeMessage>
 
+#include <Akonadi/Collection>
 #include <Akonadi/KMime/AddressAttribute>
-#include <AkonadiCore/Collection>
 
 using namespace Akonadi;
 using namespace KMime;
