@@ -8,11 +8,15 @@
 
 #include <mailtransportakonadi_export.h>
 
-#include <attribute.h>
-#include <collection.h>
+#include <Akonadi/Attribute>
+#include <Akonadi/Collection>
+
+#include <memory>
 
 namespace MailTransport
 {
+class SentBehaviourAttributePrivate;
+
 /**
   Attribute determining what will happen to a message after it is sent.  The
   message can be deleted from the Outbox, moved to the default sent-mail
@@ -94,8 +98,7 @@ public:
     void setSendSilently(bool sendSilently);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<SentBehaviourAttributePrivate> const d;
 };
 } // namespace MailTransport
 
