@@ -4,16 +4,18 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORTATTRIBUTE_H
-#define MAILTRANSPORT_TRANSPORTATTRIBUTE_H
+#pragma once
 
 #include <mailtransportakonadi_export.h>
 
-#include <attribute.h>
+#include <Akonadi/Attribute>
+
+#include <memory>
 
 namespace MailTransport
 {
 class Transport;
+class TransportAttributePrivate;
 
 /**
   Attribute determining which transport to use for sending a message.
@@ -61,9 +63,7 @@ public:
     void setTransportId(int id);
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<TransportAttributePrivate> const d;
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORTATTRIBUTE_H
